<?php
/**
 * Déclaration de la classe CommandLine\Argument\Parser\RegexParser
 */
namespace jrosset\CommandLine\Argument\Parser;

use RangeException;

/**
 * Parseur vers une chaine de caractère correspondant à un motif
 *
 * Renvoie la liste des groupes capturants
 *
 * @package CommandLine\Argument\Parser
 */
class RegexParser implements IValueParser {
    /**
     * @var string La regex à respecter
     */
    protected $_regex = '';
    /**
     * @var string|null Le format affiché dans la description
     */
    protected $_format = '';

    /**
     * Crée un nouveau parseur
     *
     * @param string $regex Le motif à respecter
     * @param string|null $format Le format à afficher
     */
    public function __construct ($regex, $format = null) {
        $this->setRegex($regex);
        $this->setFormat($format);
    }

    /**
     * @inheritDoc
     */
    public function parseValue ($arg) {
        if(!preg_match($this->_regex, $arg, $matches))
            throw new RangeException('La valeur ne correspond pas au motif attendu : ' . $arg);

        return $matches;
    }

    /**
     * @inheritDoc
     */
    public function getValueDescription () {
        return is_null($this->getFormat()) ? $this->getRegex() : $this->getFormat();
    }

    /**
     * Le motif à respecter
     *
     * @return string Le motif
     *
     * @see $_regex
     */
    public function getRegex() {
        return $this->_regex;
    }
    /**
     * Modifie le motif à respecter
     *
     * @param string $regex Le nouveau motif
     *
     * @return $this
     */
    public function setRegex($regex) {
        $this->_regex = $regex;
        return $this;
    }

    /**
     * Le format à afficher
     *
     * @return string|null Le format
     *
     * @see $_format
     */
    public function getFormat() {
        return $this->_format;
    }
    /**
     * Modifie le format à afficher
     *
     * @param string|null $format Le nouveau format
     *
     * @return $this
     */
    public function setFormat($format = null) {
        $this->_format = $format;
        return $this;
    }
}